.. currentmodule:: pyfits

*************
Opening Files
*************

.. autofunction:: open

.. automodule:: pyfits.convenience
   :members: getdata, getheader, getval, setval, delval, writeto, append,
             update, info

